import greenfoot.*;

/**
 * A house occupied by a person that loves waving his hands.
 * 
 * INFORMATION ON USE:
 * The classes you need to copy over into your scenario are 
 * Skit, Scene, and Animated. The Skit class represents an
 * animation performed by your object, the Scene class
 * represents a specific image shown in the animation, and
 * the Animated class is the superclass for all actors that
 * need to be animated.
 *
 *
 *
 * To design your own scenario using these classes, you must
 * have a thorough understanding of basic Java and Greenfoot
 * skills. If you are uploading your scenario to the 
 * Greenfoot, DO NOT change any of the code or comments
 * in the Skit, Scene, or Animated classes.
 * 
 * 
 * 
 * To make your own animated actor class, first create a 
 * subclass of the Animated class. In the act() method, 
 * write the line:
 * 
 * run();
 * 
 * This allows any current animations to take place. Next, 
 * create a constructor like this:
 * 
 * public <identifier>()
 * {
 *     
 * }
 * 
 * Next, you will want to add the constructor and assignment
 * for each of the Skits. For example:
 * 
 * public <identifier>()
 * {
 *     Skit dance = new Skit( ,  );
 *     
 *     Skit sleep = new Skit( ,  );
 * }
 * 
 * Replace the first second blanks with the ID:
 * 
 * public <identifier>()
 * {
 *     Skit dance = new Skit( , "Dance");
 *     
 *     Skit sleep = new Skit( , "Sleep");
 * }
 * 
 * Now comes the tricky part. First, in the first blanks, 
 * insert an array constructor like this:
 * 
 * public <identifier>()
 * {
 *     Skit dance = new Skit(new Scene[]{...}, "Dance");
 *     
 *     Skit sleep = new Skit(new Scene[]{...}, "Sleep");
 * }
 * 
 * Then, I like to put all of the scenes on new lines, so:
 * 
 * public <identifier>()
 * {
 *     Skit dance = new Skit(new Scene[]{
 *         ...
 *      }, "Dance");
 *     
 *     Skit sleep = new Skit(new Scene[]{
 *         ...
 *      }, "Sleep");
 * }
 * 
 * In place of the '...', add all of the scenes, like this:
 * 
 * public <identifier>()
 * {
 *     Skit dance = new Skit(new Scene[]{
 *         new Scene(0, new GreenfootImage("left.png")),
 *         new Scene(10, new GreenfootImage("right.png")),
 *         new Scene(20, new GreenfootImage("left.png")),
 *         new Scene(30, new GreenfootImage("right.png")),
 *         new Scene(40, new GreenfootImage("down.png"))
 *      }, "Dance");
 *     
 *     Skit sleep = new Skit(new Scene[]{
 *         new Scene(20, new GreenfootImage("bent over.png")),
 *         new Scene(40, new GreenfootImage("one arm.png")),
 *         new Scene(60, new GreenfootImage("both arms.png")),
 *         new Scene(80, new GreenfootImage("side.png")),
 *         new Scene(115, new GreenfootImage("back.png")),
 *         new Scene(130, new GreenfootImage("blankets.png"))
 *      }, "Sleep");
 * }
 * 
 * Now, to prevent slowness, add this clause to the end of
 * the array:
 * 
 * new Scene(<last + 1>, null)
 * 
 * like this:
 * 
 * public <identifier>()
 * {
 *     Skit dance = new Skit(new Scene[]{
 *         new Scene(0, new GreenfootImage("left.png")),
 *         new Scene(10, new GreenfootImage("right.png")),
 *         new Scene(20, new GreenfootImage("left.png")),
 *         new Scene(30, new GreenfootImage("right.png")),
 *         new Scene(40, new GreenfootImage("down.png")),
 *         new Scene(41, null)
 *      }, "Dance");
 *     
 *     Skit sleep = new Skit(new Scene[]{
 *         new Scene(20, new GreenfootImage("bent over.png")),
 *         new Scene(40, new GreenfootImage("one arm.png")),
 *         new Scene(60, new GreenfootImage("both arms.png")),
 *         new Scene(80, new GreenfootImage("side.png")),
 *         new Scene(115, new GreenfootImage("back.png")),
 *         new Scene(130, new GreenfootImage("blankets.png")),
 *         new Scene(131, null)
 *      }, "Sleep");
 * }
 * 
 * Finally, add all of your Skits to the list by doing
 * addSkit(skit);:
 * 
 * public <identifier>()
 * {
 *     Skit dance = new Skit(new Scene[]{
 *         new Scene(0, new GreenfootImage("left.png")),
 *         new Scene(10, new GreenfootImage("right.png")),
 *         new Scene(20, new GreenfootImage("left.png")),
 *         new Scene(30, new GreenfootImage("right.png")),
 *         new Scene(40, new GreenfootImage("down.png")),
 *         new Scene(41, null)
 *      }, "Dance");
 *     
 *     Skit sleep = new Skit(new Scene[]{
 *         new Scene(20, new GreenfootImage("bent over.png")),
 *         new Scene(40, new GreenfootImage("one arm.png")),
 *         new Scene(60, new GreenfootImage("both arms.png")),
 *         new Scene(80, new GreenfootImage("side.png")),
 *         new Scene(115, new GreenfootImage("back.png")),
 *         new Scene(130, new GreenfootImage("blankets.png")),
 *         new Scene(131, null)
 *      }, "Sleep");
 *      
 *      addSkit(sleep);
 *      addSkit(dance);
 * }
 * 
 * There, done! Don't worry, you'll get the hang of it, I did.
 * (Then again, I made it)
 * 
 * @author TriMil 
 * @version 1.0
 */
public class House extends World
{
    /**
     * Creates a new House with a hand-waving occupant.
     * 
     */
    public House()
    {    
        super(600, 400, 1); // Makes a nice, comfy brick house
        addObject(new Person(), getWidth()/2, getHeight()/2); // Add a person, but no ordinary person.
    }
}
