import greenfoot.*;

/**
 * A person that waves his hands when the spacebar is pressed.
 * 
 *      "I love waving my hands!"
 *                -Person
 * 
 * For more details in all explanations, look in the world subclass.
 * 
 * @author TriMil
 * @version 1.0
 */
public class Person extends Animated
{
    /**
     * Image with arms up
     */
    private GreenfootImage up = new GreenfootImage("person up.png");
    
    /**
     * Image with arms down
     */
    private GreenfootImage down = new GreenfootImage("person down.png");
    
    /**
     * Image with arms flat
     */
    private GreenfootImage norm = new GreenfootImage("person.png");
    
    /**
     * Is the spacebar down?
     */
    private boolean spaceDown = false;
    
    /**
     * Creates a new person with a single skit: arm-waving.
     */
    public Person()
    {
        Skit s = new Skit(new Scene[]{  // Creates a new skit with the following scenes:
            new Scene(0, up),           // After 0 ticks: raise the arms
            new Scene(20, down),        // After 20 ticks: lower the arms
            new Scene(40, up),          // After 40 ticks: raise the arms
            new Scene(60, down),        // After 60 ticks: lower the arms
            new Scene(80, norm),        // After 800 ticks: return arms to normal
            new Scene(81, null)},       // After 81 ticks: end the skit. All skits should have an end, or things might get laggy.
            "Wave"                      // This is the skit's ID
        );
        
        /*
         * Line 46 is there because I want the arms to be normal again after the skit ends.
         * If you are doing something like sleeping, when the character should only wake up
         * when a new skit is played, omit that line.
         */
        
        addSkit(s); // Add the skit to the list
    }
    
    /**
     * Checks for spacebar presses. If one is detected, play the "Wave" skit
     */
    public void act() 
    {
        run(); // Must be called at the beginning of the act() method
        
        if(Greenfoot.isKeyDown("SPACE") && !spaceDown) // If the spacebar was just pressed...
        {
            startSkit("Wave");                         // ...Start waving arms
            spaceDown = true;                          // and remember the spacebar is pressed.
        }
        if(!Greenfoot.isKeyDown("SPACE") && spaceDown) // If the spacebar was just released...
        {
            spaceDown = false;                         // ...remember the spacebar is not pressed.
        }
    }    
}
